@@ -9,7 +9,7 @@ use vortex_dtype::{
     match_each_integer_ptype, match_each_unsigned_integer_ptype, NativePType, PType,
 };
 use vortex_error::{vortex_bail, vortex_err, VortexResult, VortexUnwrap};
-use vortex_scalar::Scalar;
+use vortex_scalar::{Scalar, ScalarValue};
 
 use crate::BitPackedArray;
 
@@ -40,6 +40,30 @@ pub fn bitpack_encode(array: PrimitiveArray, bit_width: usize) -> VortexResult<B
     )
 }
 
+/// Bitpack an array into the specified bit-width without checking statistics.
+///
+/// # Safety
+///
+/// It is the caller's responsibility to ensure that all values in the array can lossless pack
+/// into the specified bit-width.
+///
+/// Failure to do so will result in data loss.
+pub unsafe fn bitpack_encode_unchecked(
+    array: PrimitiveArray,
+    bit_width: usize,
+) -> VortexResult<BitPackedArray> {
+    let packed = bitpack(&array, bit_width)?;
+
+    BitPackedArray::try_new(
+        packed,
+        array.ptype(),
+        array.validity(),
+        None,
+        bit_width,
+        array.len(),
+    )
+}
+
 /// Bitpack a [PrimitiveArray] to the given width.
 ///
 /// On success, returns a [Buffer] containing the packed data.
@@ -131,7 +155,7 @@ pub fn bitpack_patches(
                 indices.into_array(),
                 PrimitiveArray::from_vec(values, Validity::AllValid).into_array(),
                 parray.len(),
-                Scalar::null(parray.dtype().as_nullable()),
+                ScalarValue::Null,
             )
             .vortex_unwrap()
             .into_array()
