@@ -7,23 +7,21 @@ use crate::stats::{ArrayStatisticsCompute, Stat, StatsSet};
 use crate::validity::{ArrayValidity, LogicalValidity, Validity};
 use crate::variants::{ArrayVariants, NullArrayTrait};
 use crate::visitor::{AcceptArrayVisitor, ArrayVisitor};
-use crate::{impl_encoding, ArrayDef, ArrayTrait, Canonical, IntoCanonical};
+use crate::{impl_encoding, ArrayTrait, Canonical, IntoCanonical};
 
 mod compute;
 
 impl_encoding!("vortex.null", ids::NULL, Null);
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
-pub struct NullMetadata {
-    len: usize,
-}
+pub struct NullMetadata;
 
 impl NullArray {
     pub fn new(len: usize) -> Self {
         Self::try_from_parts(
             DType::Null,
             len,
-            NullMetadata { len },
+            NullMetadata,
             [].into(),
             StatsSet::nulls(len, &DType::Null),
         )
