@@ -8,9 +8,7 @@ use crate::stats::{ArrayStatisticsCompute, StatsSet};
 use crate::validity::{ArrayValidity, LogicalValidity, Validity, ValidityMetadata};
 use crate::variants::{ArrayVariants, StructArrayTrait};
 use crate::visitor::{AcceptArrayVisitor, ArrayVisitor};
-use crate::{
-    impl_encoding, Array, ArrayDType, ArrayDef, ArrayTrait, Canonical, IntoArray, IntoCanonical,
-};
+use crate::{impl_encoding, Array, ArrayDType, ArrayTrait, Canonical, IntoArray, IntoCanonical};
 
 mod compute;
 
@@ -18,7 +16,6 @@ impl_encoding!("vortex.struct", ids::STRUCT, Struct);
 
 #[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct StructMetadata {
-    length: usize,
     validity: ValidityMetadata,
 }
 
@@ -74,7 +71,6 @@ impl StructArray {
             DType::Struct(StructDType::new(names, field_dtypes), nullability),
             length,
             StructMetadata {
-                length,
                 validity: validity_metadata,
             },
             children.into(),
